/* KallistiGL for KOS 1.1.6

   glmisc.c
   (c)2001 Dan Potter
*/

#include <GL/gl.h>
#include <GL/glu.h>
#include "glinternal.h"

#include <stdio.h>

CVSID("$Id: glmisc.c,v 1.5 2002/01/06 00:40:33 bardtx Exp $");

/* Miscellaneous APIs */

/* Set the background clear color */
void glClearColor(GLclampf red,
		GLclampf green,
		GLclampf blue,
		GLclampf alpha) {
	gl_clear_color[0] = red;
	gl_clear_color[1] = green;
	gl_clear_color[2] = blue;
	gl_clear_color[3] = alpha;
}

/* NOP: there's nothing to clear on the PVR2 */
void glClear(GLbitfield mask) {
}

/* Set face culling mode */
void glCullFace(GLenum mode) {
	switch(mode) {
	case GL_FRONT:
		if (gl_cull_mode != GL_FRONT)
			gl_pbuf_submitted = GL_FALSE;
		gl_cull_mode = GL_FRONT;
		break;
	case GL_BACK:
		if (gl_cull_mode != GL_BACK)
			gl_pbuf_submitted = GL_FALSE;
		gl_cull_mode = GL_BACK;
		break;
	}
}

/* Enable / disable capabilities */
void glEnable(GLenum cap) {
	switch(cap) {
	case GL_TEXTURE_2D:
		gl_pbuf_submitted = GL_FALSE;
		break;
	case GL_BLEND:
		if (gl_active_list != GL_LIST_TRANS_POLY) {
			dbglog(DBG_ERROR, "gl: invalid list to enable GL_BLEND inside");
			return;
		}
		break;
	case GL_CULL_FACE:
	        if (gl_cull_face != GL_TRUE)
		    gl_pbuf_submitted = GL_FALSE;
	        gl_cull_face = GL_TRUE;
	        break;
	}

	gl_capabilities |= (GLbitfield)cap;
}

void glDisable(GLenum cap) {
	switch(cap) {
	case GL_TEXTURE_2D:
		gl_pbuf_submitted = GL_FALSE;
		gl_cur_texture = &gl_null_texture;
		break;
	case GL_BLEND:
		if (gl_active_list == GL_LIST_TRANS_POLY) {
			dbglog(DBG_ERROR, "gl: invalid list to disable GL_BLEND inside");
			return;
		}
		break;
	case GL_CULL_FACE:
	        if (gl_cull_face != GL_FALSE)
		    gl_pbuf_submitted = GL_FALSE;
	        gl_cull_face = GL_FALSE;
	        break;
	}

	gl_capabilities &= ~((GLbitfield)cap);
}

/* We have no rendering pipeline yet, so this is a NOP */
void glFlush() {
}

/* There aren't any useful hints to set yet, so this is a NOP */
void glHint(GLenum target, GLenum mode) {
}



